@@ -1,8 +1,8 @@
 ;;; lookup.el --- Search interface to electronic dictionaries
-;; Copyright (C) 1999 Lookup Development Team <lookup@ring.gr.jp>
+;; Copyright (C) 1999-2001 Lookup Development Team <lookup@ring.gr.jp>
 
 ;; Author: Keisuke Nishida <kei@psn.net>
-;; Version: $Id: lookup.el,v 1.7 1999/08/09 07:27:13 tsuchiya Exp $
+;; Version: $Id: lookup.el,v 1.6 2004/01/27 09:09:49 kazuhiko Exp $
 
 ;; This file is part of Lookup.
 
@@ -540,7 +540,8 @@ ID $B$O<-=q(BID$B!#(BTAG $B$O%*%W%7%g%s$N%?%0!#(BVALUE $B$O%;%C%H$9$kCM!#
 	(switch-to-buffer (other-buffer)))))
   (if (window-live-p lookup-main-window)
       (select-window lookup-main-window))
-  (bury-buffer buffer))
+  (if (buffer-live-p buffer)
+      (bury-buffer buffer)))
 
 (defun lookup-pop-to-buffer (buffer)
   (if (and (window-live-p lookup-main-window)
@@ -613,6 +614,101 @@ ID $B$O<-=q(BID$B!#(BTAG $B$O%*%W%7%g%s$N%?%0!#(BVALUE $B$O%;%C%H$9$kCM!#
        ((eq work t) (message "%s" (concat message "done")))
        (t (message "%s" (concat message " (" work ")")))))))
 
+(eval-when-compile
+  (defvar lookup-logo-file (if (or (featurep 'xemacs)
+				   (and (condition-case nil
+					    (require 'image)
+					  (error nil))
+					(image-type-available-p 'xpm)))
+			       "lookup-logo.xpm"
+			     "lookup-logo.xbm"))
+  (defmacro logo-image ()
+    (with-temp-buffer
+      (cond ((featurep 'xemacs)
+	     (let ((format-alist nil))
+	       (insert-file-contents lookup-logo-file)))
+	    ((and (condition-case nil
+		      (require 'image)
+		    (error nil))
+		  (image-type-available-p 'xpm)))
+	    ((locate-library "bitmap")
+	     (require 'bitmap)
+	     (bitmap-insert-xbm-file lookup-logo-file)
+	     (put-text-property (point-min) (point-max)
+				'face 'lookup-splash-face))
+	    (t ))
+       (buffer-substring (point-min) (point-max))))
+  (defmacro logo-image-xpm ()
+    (with-temp-buffer
+      (if (and (condition-case nil
+		   (require 'image)
+		 (error nil))
+	       (image-type-available-p 'xpm))
+	  (progn
+	    (insert-file-contents lookup-logo-file)
+	    (re-search-forward
+	     (concat "\"[\t ]*\\([0-9]+\\)[\t ]+\\([0-9]+\\)"
+		     "[\t ]+[0-9]+[\t ]+[0-9]+[\t ]*\""))
+	    (list 'list
+		  (string-to-number (match-string 1))
+		  (string-to-number (match-string 2))
+		  (buffer-string)))))))
+
+(defconst lookup-logo-image (logo-image))
+
+(defun lookup-splash ()
+  (interactive)
+  (when (and lookup-enable-splash window-system
+ 	     (or lookup-use-bitmap (featurep 'image) (featurep 'xemacs)))
+    (let ((buffer (get-buffer-create "*Lookup Logo*")))
+      (set-buffer buffer)
+      (setq fill-column (window-width))
+      (erase-buffer)
+       (cond ((featurep 'xemacs)
+	      (let ((logo-glyph
+		     (make-glyph (vector 'xpm :data lookup-logo-image)))
+		    logo-ext)
+		(indent-to (startup-center-spaces logo-glyph))
+		(setq logo-ext (make-extent (point) (point)))
+		(set-extent-end-glyph logo-ext logo-glyph)))
+	     ((and (condition-case nil
+		       (require 'image)
+		     (error nil))
+		   (image-type-available-p 'xpm))
+	      (let* ((ww (window-width))
+		     (wh (window-height))
+		     (xpm (logo-image-xpm))
+		     (lw (car xpm))
+		     (lh (nth 1 xpm))
+		     (image
+		      (create-image (nth 2 xpm) 'xpm t)))
+		(insert (propertize " " 'display
+				    (list 'space ':align-to
+					  (max 0 (/ (- (* (frame-char-width)
+							  (1+ ww)) lw)
+						    2 (frame-char-width))))))
+		(insert-image image)))
+	     (t
+	      (center-region (point-min)(point-max))
+	      (insert lookup-logo-image)
+	      (goto-char (1- (point-max)))
+	      (indent-rigidly (point-min) (point-max)
+			      (max 0 (/ (- (window-width)
+					   (current-column)) 2)))))
+       (goto-char (point-max))
+       (let((pt (point))
+	    (line (count-lines (point-min)(point-max))))
+	 (insert (format "\nLookup %s\n\n" lookup-version))
+	 (insert "Copyright (C) 2000, 2001 Lookup Development Team")
+	 (insert "\n<lookup@ring.gr.jp>\n")
+	 (center-region pt (point-max))
+	 (goto-char (point-min))
+	 (insert-char ?\n 
+		      (max 1 (+ -5 (/ (- (window-height) line) 2)))))
+       (switch-to-buffer buffer)
+       (sit-for 3)
+      (kill-buffer buffer))))
+
 
 ;;;
 ;:: Lookup Initialize
@@ -621,6 +717,7 @@ ID $B$O<-=q(BID$B!#(BTAG $B$O%*%W%7%g%s$N%?%0!#(BVALUE $B$O%;%C%H$9$kCM!#
 (defun lookup-initialize ()
   (load lookup-init-file t)
   (run-hooks 'lookup-load-hook)
+  (lookup-splash)
   (lookup-init-gaiji-functions))
 
 (defun lookup-agent-list ()
